@@ -568,6 +568,8 @@ class AtomData(object):
 
         # Iterate through the atoms
         def iterate_atoms(structure):
+            if isinstance(structure, gemmi.Model):
+                structure = [structure]
             for model_index, model in enumerate(structure):
                 for chain in model:
                     for residue in chain:
@@ -610,7 +612,16 @@ class AtomData(object):
         """
 
         # Read the structure
-        return Class.from_gemmi_structure(gemmi.read_structure(filename))
+        structure = gemmi.read_structure(filename)
+
+        # Create ensemble with default first biological assembly
+        if len(structure.assemblies) > 0 and len(structure) > 0:
+            structure = gemmi.make_assembly(
+                structure.assemblies[0],
+                structure[0],
+                gemmi.HowToNameCopiedChain.AddNumber,
+            )
+        return Class.from_gemmi_structure(structure)
 
     @classmethod
     def from_ligand_file(Class, filename):
